/*
Example for Brushless_2 Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration CEC :
    
    MCU             : CEC1702
    Dev. Board      : Clicker 2 for CEC1702
    SW              : mikroC PRO for ARM v5.1.0

Description :

    This simple example demonstrates driving the motor with Brushless 2 click, direction of motor is controled via MOTOR_DIR_PIN and speed is regulated with PWM.

*/
#include "stdint.h"

sbit MOTOR_DIR_PIN at GPIO_OUTPUT_040_047.B5; 

uint16_t currentDuty = 0;

void systemInit()
{
    Gpio_Digital_Output(&GPIO_PORT_040_047, _GPIO_PINMASK_5);
    currentDuty = PWM10_Init(15000);                 // Set PWM frequency/period (according to the DC motor characteristics)
    PWM10_Set_Duty(currentDuty,  _PWM_NON_INVERTED);   // Set current duty for PWM
    PWM10_Start();
}

void Brushless_2_Init()
{
    MOTOR_DIR_PIN = 1;
}

void Brushless_2_Task()
{
    MOTOR_DIR_PIN  = 0;
    //Forward fast
    currentDuty = PWM10_Init(15000);                 // Set PWM frequency/period (according to the DC motor characteristics)
    PWM10_Set_Duty(currentDuty,  _PWM_NON_INVERTED);   // Set current duty for PWM
    PWM10_Start();
    Delay_ms (3000);
    //Forward slow
    currentDuty = PWM10_Init(15000);                 // Set PWM frequency/period (according to the DC motor characteristics)
    PWM10_Set_Duty(currentDuty/2,  _PWM_NON_INVERTED);   // Set current duty for PWM
    PWM10_Start();
    Delay_ms (3000);
    //Reverse
    MOTOR_DIR_PIN = 1;
    //Reverse fast
    currentDuty = PWM10_Init(15000);                 // Set PWM frequency/period (according to the DC motor characteristics)
    PWM10_Set_Duty(currentDuty,  _PWM_NON_INVERTED);   // Set current duty for PWM
    PWM10_Start();
    Delay_ms (3000);
    //Reverse slow
    currentDuty = PWM10_Init(15000);                 // Set PWM frequency/period (according to the DC motor characteristics)
    PWM10_Set_Duty(currentDuty/2,  _PWM_NON_INVERTED);   // Set current duty for PWM
    PWM10_Start();
    Delay_ms (3000);

}

void main()
{
    systemInit();
    Brushless_2_Init();

    while( 1 )
    {
    	Brushless_2_Task();
    }
}


