/*
Example for Brushless_2 Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration STM32 :
    
    MCU             : STM32F107VCT6
    Dev. Board      : EasyMx PRO v7 for STM32 ARM
    SW              : mikroC PRO for ARM v5.1.0

Description :

    This simple example demonstrates driving the motor with Brushless 2 click, 
    direction of motor is controled via MOTOR_DIR_PIN and speed is regulated with PWM.
    Board specific: Button press level PORTA to VCC, and GPIO PORTA/L pull down PA6 and PA5, 
    speed is controlled by pressing PA6 and direction is changed by pressing PA5.
    
*/
#include "stdint.h"

sbit MOTOR_DIR_PIN at GPIOC_ODR.B2;

uint16_t const maxPwmDuty = 5000;
uint16_t currentDuty = 0;
uint8_t oldstate = 0;

void systemInit()
{
    GPIO_Digital_Output( &GPIOC_BASE, _GPIO_PINMASK_2 );
    currentDuty = PWM_TIM5_Init(5000);
    PWM_TIM5_Set_Duty(currentDuty,  _PWM_NON_INVERTED, _PWM_CHANNEL1);
    PWM_TIM5_Start(_PWM_CHANNEL1, &_GPIO_MODULE_TIM5_CH1_PA0);
}

void Brushless_2_Init()
{
    MOTOR_DIR_PIN = 1;
}

void Brushless_2_Task()
{
    if (Button(&GPIOA_IDR, 6, 1, 1))
    {
        currentDuty++;
        PWM_TIM5_Set_Duty(currentDuty,  _PWM_NON_INVERTED, _PWM_CHANNEL1);
        if (currentDuty > maxPwmDuty)      
            currentDuty = 0;              
        
    }
     
    if (Button(&GPIOA_IDR, 5, 1, 1))
    {                                               
        oldstate = 1;                              
    }
    if (oldstate && Button(&GPIOA_IDR, 5, 1, 0))
    {   
        MOTOR_DIR_PIN = ~MOTOR_DIR_PIN;                              
        oldstate = 0;   
    }

}

void main()
{
    systemInit();
    Brushless_2_Init();

    while( 1 )
    {
            Brushless_2_Task();
    }
}