/*
Example for Brushless_2 Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration TIVA :
    
    MCU             : TM4C129XNCZAD
    Dev. Board      : EasyMx PRO v7 for TIVA ARM
    SW              : mikroC PRO for ARM v5.1.0

Description :

    This simple example demonstrates driving the motor with Brushless 2 click, 
    direction of motor is controled via MOTOR_DIR_PIN and speed is regulated with PWM.
    Board specific: Button press level PORTB to VCC, and PORTB/H pull down PB0 and PB4, 
    speed is controlled by pressing PB0 and direction is changed by pressing PB4.

*/
#include "stdint.h"

sbit MOTOR_DIR_PIN at GPIO_PORTE_AHB_DATA.B0; 

uint16_t const maxPwmDuty = 10000;
uint16_t currentDuty = 0;
uint8_t oldstate = 0;

void systemInit()
{
    GPIO_Digital_Output(&GPIO_PORTE_AHB, _GPIO_PINMASK_0 );
    GPIO_Digital_Output(&GPIO_PORTD_AHB, _GPIO_PINMASK_0 );
    GPIO_Digital_Input(&GPIO_PORTB_AHB_DATA_BITS, _GPIO_PINMASK_0);
    GPIO_Digital_Input(&GPIO_PORTB_AHB_DATA_BITS, _GPIO_PINMASK_4);
    currentDuty = PWM_T0CCP0_Init (10000, &_GPIO_MODULE_T0CCP0_D0_AHB);
    PWM_T0CCP0_Set_Duty(currentDuty, _PWM_INVERTED_DISABLE );
    PWM_T0CCP0_Start();
}

void Brushless_2_Init()
{
    MOTOR_DIR_PIN = 1;
}

void Brushless_2_Task()
{
    if (Button(&GPIO_PORTB_AHB_DATA, 0, 1, 1))
    {
        currentDuty++;
        PWM_T0CCP0_Set_Duty(currentDuty, 0);
        if (currentDuty > maxPwmDuty)      
            currentDuty = 0;              
        
    }
     
    if (Button(&GPIO_PORTB_AHB_DATA, 4, 1, 1))
    {                                               
        oldstate = 1;                              
    }
    if (oldstate && Button(&GPIO_PORTB_AHB_DATA, 4, 1, 0))
    {   
        MOTOR_DIR_PIN = ~MOTOR_DIR_PIN;                              
        oldstate = 0;   
    }

}

void main()
{
    systemInit();
    Brushless_2_Init();

    while( 1 )
    {
            Brushless_2_Task();
    }
}